@@ -5,14 +5,24 @@ np.boot <-
            parallel = FALSE, cl = NULL, boot.dist = TRUE){
     # Nonparametric Bootstrap (SE, Bias, and CIs)
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: 2023-04-14
+    # last updated: 2026-01-15
     
     
     ######***######   CHECKS   ######***######
     
     ### check x
-    x <- as.vector(x)
-    nobs <- length(x)
+    if(is.matrix(x) | is.data.frame(x)){
+      xdf <- TRUE
+      thedataframe <- as.data.frame(x)
+      nobs <- nrow(thedataframe)
+      x <- 1:nobs
+      statfun <- statistic
+      statistic <- function(ix, ...) statfun(thedataframe[ix,], ...)
+    } else {
+      xdf <- FALSE
+      x <- as.vector(x)
+      nobs <- length(x)
+    }
     
     ### check statistic
     statistic <- as.function(statistic)
@@ -76,6 +86,10 @@ np.boot <-
         jackknife <- statistic
       } else {
         jackknife <- as.function(jackknife)
+        if(xdf) {
+          jackfun <- jackknife
+          jackknife <- function(ix, ...) jackfun(thedataframe[ix,], ...) 
+        }
         j0 <- jackknife(x, ...)
         if(length(j0) != nstat) stop("Outputs of 'statistic' and 'jackknife' functions must have the same length")
       }
