@@ -6,7 +6,7 @@ rand.test.lm1 <-
            perm.dist = TRUE){
     # Randomization Test for Regression (w/o covariates)
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: 2023-04-14
+    # last updated: 2026-01-15
     
     
     #########   INITIAL CHECKS   #########
@@ -301,9 +301,9 @@ rand.test.lm1 <-
     if(!perm.dist) permdist <- NULL
     res <- list(statistic = Tstat, p.value = p.value,
                 perm.dist = permdist, method = method, 
-                null.value = beta, homosced = homosced, 
-                R = nperm - ifelse(exact, 0, 1), exact = exact,
-                coefficients = coefs)
+                null.value = beta, homosced = homosced,
+                lambda = lambda, R = nperm - ifelse(exact, 0, 1), 
+                exact = exact, coefficients = coefs)
     if(nvar > 1L) {
       res$univariate <- Tuni
       res$adj.p.values <- uni.p.value
