@@ -7,7 +7,7 @@ rand.test.lm2 <-
            perm.dist = TRUE){
     # Randomization Test for Regression (w/ covariates)
     # Nathaniel E. Helwig (helwig@umn.edu)
-    # last updated: 2023-04-14
+    # last updated: 2026-01-15
     
     # Methods with Z:
     # ---  permute X
@@ -356,8 +356,8 @@ rand.test.lm2 <-
     res <- list(statistic = Tstat, p.value = p.value,
                 perm.dist = permdist, method = method, 
                 null.value = beta, homosced = homosced, 
-                R = nperm - ifelse(exact, 0, 1), exact = exact,
-                coefficients = coefs)
+                lambda = lambda, R = nperm - ifelse(exact, 0, 1), 
+                exact = exact, coefficients = coefs)
     if(nvar > 1L) {
       res$univariate <- Tuni
       res$adj.p.values <- uni.p.value
